# Blue Yonder
&nbsp;&nbsp;&nbsp;&nbsp;This is a Bluesky Python API for humans. It can be used for the simple automations that you _know_ should be implemented, but they are just 'not there' in a pretty annoying way. But you know how to program in Python... And you have an IDE like PyCharm(R), VSCode or even Cursor or Windsurf...
<br>&nbsp;&nbsp;&nbsp;&nbsp;Here comes the `blue-yonder` Python package. It has been built with a perspective of a person who does not need (or want any of) the professional jargon of software engineers and 'coders'. The logged in entity that performs **actions** is called **Actor**; the **other** entity whose profile or post is brought into focus is called **Another**; the other useful functionality of the network is in the **yonder** module. It's that simple.

## Installation
```Bash
  pip install blue-yonder
```
Note: the pip package name has a dash `-` between the words.

Then:
```Python
# Python

from blue_yonder import Actor, Another, yonder
```
Note: the module name has an underscore `_` between the words.
## How to use it
&nbsp;&nbsp;&nbsp;&nbsp;I didn't want to overload this repository and library, - you can use the 'template repository' with multiple examples, that I considered to be useful for myself when I was studying the Bluesky API. It is located [here](https://github.com/alxfed/butterfly). Just click the 'Use this template' button at the top of that page and create your own repository in your (or your organization) account that you can edit and use the way you deem fit. I will keep working on it too, so you can be sure that it will be updated as I make changes.